tsseg.algorithms.time2state package
===================================

Causal CNN encoder → DPGMM clustering for state labels.

| **Type:** state detection
| **Supervision:** unsupervised
| **Requires:** PyTorch

**Implementation:** Taken from https://github.com/Lab-ANT/Time2State. No licence
specified.

**Reference:** Zheng et al. (2023), PVLDB.

Submodules
----------

tsseg.algorithms.time2state.detector module
-------------------------------------------

.. automodule:: tsseg.algorithms.time2state.detector
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.time2state.time2state module
---------------------------------------------

.. automodule:: tsseg.algorithms.time2state.time2state
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.time2state
   :members:
   :show-inheritance:
   :undoc-members:
